@@ -1,5 +1,5 @@
 package List::Compare;
-$VERSION = 0.18;   # June 1, 2003 
+$VERSION = 0.19;   # June 1, 2003 
 use strict;
 # use warnings; # commented out so module will run on pre-5.6 versions of Perl
 use Carp;
@@ -354,13 +354,17 @@ List::Compare - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.18 of List::Compare.  This version was
+This document refers to version 0.19 of List::Compare.  This version was
 released June 1, 2003.
 
 =head1 SYNOPSIS
 
 =head2 Regular Case:  Compare Two Lists
 
+=over 4
+
+=item *
+
 Create a List::Compare object.  Put the two lists into arrays and pass
 references to the arrays to the constructor.
 
@@ -369,24 +373,34 @@ references to the arrays to the constructor.
 
     $lc = List::Compare->new(\@Llist, \@Rlist);
 
+=item *
+
 Get those items which appear at least once in both lists (their intersection).
 
     @intersection = $lc->get_intersection;
 
+=item *
+
 Get those items which appear at least once in either list (their union).
 
     @union = $lc->get_union;
 
+=item *
+
 Get those items which appear (at least once) only in the first list.
 
     @Lonly = $lc->get_unique;
     @Lonly = $lc->get_Lonly;    # alias
 
+=item *
+
 Get those items which appear (at least once) only in the second list.
 
     @Ronly = $lc->get_complement;
     @Ronly = $lc->get_Ronly;            # alias
 
+=item *
+
 Get those items which appear at least once in either the first or the second 
 list, but not both.
 
@@ -394,12 +408,16 @@ list, but not both.
     @LorRonly = $lc->get_symdiff;       # alias
     @LorRonly = $lc->get_LorRonly;      # alias
 
+=item *
+
 Make a bag of all those items in both lists.  The bag differs from the 
 union of the two lists in that it holds as many copies of individual 
 elements as appear in the original lists.
 
     @bag = $lc->get_bag;
 
+=item *
+
 An alternative approach to the above methods:  If you do not immediately 
 require an array as the return value of the method call, but simply need 
 a I<reference> to an array, use one of the following parallel methods:
@@ -415,6 +433,8 @@ a I<reference> to an array, use one of the following parallel methods:
     $LorRonly_ref     = $lc->get_LorRonly_ref;              # alias
     $bag_ref          = $lc->get_bag_ref;
 
+=item *
+
 Return a true value if L is a subset of R.
 
     $LR = $lc->is_LsubsetR;
@@ -423,21 +443,29 @@ Return a true value if R is a subset of L.
 
     $RL = $lc->is_RsubsetL;
 
+=item *
+
 Return a true value if L and R are equivalent, I<i.e.> if every element 
 in L appears at least once in R and I<vice versa>.
 
     $eqv = $lc->is_LequivalentR;
     $eqv = $lc->is_LeqvlntR;            # alias
 
+=item *
+
 Pretty-print a chart showing whether one list is a subset of the other.
 
     $lc->print_subset_chart;
 
+=item *
+
 Pretty-print a chart showing whether the two lists are equivalent (same 
 elements found at least once in both).
 
     $lc->print_equivalence_chart;
 
+=item *
+
 Determine in which (if any) of the lists passed to the constructor a given 
 string or strings can be found.  Get a reference to a hash of arrays where 
 an element's key is the string being tested and the element's value is a 
@@ -461,6 +489,8 @@ In the two examples above, the result will be:
          zebra    => [      ],
     };
 
+=item *
+
 Similar to the above, but testing only one string at a time.  Determine in 
 which (if any) of the lists passed to the constructor a single given 
 string can be found.  In list context, get an array holding a list of the 
@@ -483,10 +513,49 @@ In the example above, C<$memb_arr_ref> will be:
 
     [ 0, 1 ]
 
+=item *
+
+Determine if a specified string or strings can be found in any of the lists 
+passed as arguments to the constructor.  Get a reference to a hash where 
+an element's key is the string being tested and the element's value is 1 if 
+the string can be found in any of the lists and 0 if not.
+
+    $memb_hash_ref = $lc->member_any(qw| abel baker fargo hilton zebra |);
+
+Instead of passing a list to C<member_any()>, you may also pass a reference 
+to an array.
+
+    $memb_hash_ref = $lc->member_any([ qw| abel baker fargo hilton zebra | ]);
+
+In the two examples above, the result will be:
+
+    {
+         abel     => 1,
+         baker    => 1,
+         fargo    => 1,
+         hilton   => 1,
+         zebra    => 0,
+    };
+
+=item *
+
+Similar to the above, but testing only one string at a time.  Determine if a 
+specified string or strings can be found in any of the lists passed as 
+arguments to the constructor.  Return 1 if the string can be found in any of 
+the lists and 0 if not.
+
+    $found = $lc->single_member_any('abel');
+
+In the example above, C<$found> will be C<1>.
+
+=item *
+
 Return current List::Compare version number.
 
     $vers = $lc->get_version;
 
+=back
+
 =head2 Accelerated Case:  When User Only Wants a Single Comparison
 
 If you are certain that you will only want the results of a single 
