@@ -157,6 +157,31 @@ sub single_member_which {
     return wantarray ? @found : \@found;
 }    
 
+sub member_any {
+    my $class = shift;
+    croak "Method call needs at least one argument:  $!" unless (@_);
+    my %data = %$class;
+    my (@args, %present);
+    @args = (@_ == 1 and ref($_[0]) eq 'ARRAY') 
+        ?  @{$_[0]}
+        :  @_;
+    for (my $i=0; $i<=$#args; $i++) {
+    $present{$args[$i]} = ( defined $data{'seenL'}{$args[$i]} ) ||
+                              ( defined $data{'seenR'}{$args[$i]} ) ? 1 : 0;
+    }
+    return \%present;
+}    
+
+sub single_member_any {
+    my $class = shift;
+    croak "Method call requires exactly 1 argument (no references):  $!"
+        unless (@_ == 1 and ref($_[0]) ne 'ARRAY');
+    my %data = %$class;
+    my $arg = shift;
+    ( defined $data{'seenL'}{$arg} ) ||
+    ( defined $data{'seenR'}{$arg} ) ? return 1 : return 0;
+}    
+
 sub print_subset_chart {
     my $class = shift;
     my %data = %$class;
